// vincia11.cc is a part of the VINCIA plugin to PYTHIA 8
// This is a simple test program to run Z decays at LEP I and produce a HepMC
// file. Uses same settings file as vincia01.cc
// Copyright (C) 2019 Peter Skands

// PYTHIA and VINCIA include files
#include "Vincia/Vincia.h"
#include "Pythia8Plugins/HepMC2.h"

// Use PYTHIA and VINCIA namespaces
using namespace Pythia8;
using namespace Vincia;

// Main Program.
int main(int argc, char* argv[]) {

  // Check if HepMC file name is provided.
  if (argc <= 1) {
    cout << endl;
    cout << "Use the program like this: ./vincia11 HepMCfilename" << endl;
    cout << "Please specify HepMCfilename (e.g. vincia11.hepmc)." << endl;
    cout << endl;
    cout << "For passing events directly to Rivet with a fifo pipe do: " << endl;
    cout << "   mkfifo myfifo" << endl;
    cout << "   ./vincia11 myfifo &" << endl;
    cout << "   rivet --analysis=ANALYSIS_NAME myfifo" << endl;
    cout << endl;
    return 0;
  }

  // Generator.
  Pythia pythia;
  VinciaPlugin vincia(&pythia);

  // Read user settings from file.
  pythia.readFile("vincia11.cmnd");

  // Initialize Vincia & Pythia.
  vincia.init();

  // Number of events.
  int nEvent = pythia.settings.mode("Main:numberOfEvents");

  // HepMC Interface.
  HepMC::Pythia8ToHepMC ToHepMC;
  HepMC::IO_GenEvent ascii_io(argv[1], std::ios::out);

  // Begin event loop.
  for (int iEvent = 0; iEvent < nEvent; ++iEvent) {

    // Generate next event.
    if (!pythia.next()) continue;

    // HepMC.
    HepMC::GenEvent* hepmcevt = new HepMC::GenEvent();
    ToHepMC.fill_next_event( pythia, hepmcevt );
    ascii_io << hepmcevt;
    delete hepmcevt;
    
  } // End of event loop. 

  // Print infos.
  vincia.printInfo();
  pythia.stat();
  cout << endl << endl << "Produced HepMC file named " << argv[1]
       << endl << endl;
  
  // Done.
  return 0;
}
